Hello community,

here is the log from the commit of package lxc for openSUSE:Factory
checked in at Fri Apr 1 10:13:54 CEST 2011.



--------
--- lxc/lxc.changes     2011-02-28 18:20:18.000000000 +0100
+++ /mounts/work_src_done/STABLE/lxc/lxc.changes        2011-03-24 
18:04:36.000000000 +0100
@@ -1,0 +2,7 @@
+Thu Mar 24 14:22:15 UTC 2011 - [email protected]
+
+- update to 0.7.4.1
+  - fix mount path
+  - rename physical device to the original name
+
+-------------------------------------------------------------------

calling whatdependson for head-i586


Old:
----
  _service:recompress:download_url:lxc-0.7.4.tar.bz2

New:
----
  _service:recompress:download_url:lxc-0.7.4.1.tar.bz2

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ lxc.spec ++++++
--- /var/tmp/diff_new_pack.SfsvqN/_old  2011-04-01 10:09:20.000000000 +0200
+++ /var/tmp/diff_new_pack.SfsvqN/_new  2011-04-01 10:09:20.000000000 +0200
@@ -18,14 +18,14 @@
 
 
 Name:           lxc
-Version:        0.7.4
+Version:        0.7.4.1
 Release:        1
 Url:            http://lxc.sourceforge.net/
 Summary:        Linux containers implementation
 Group:          System/Management
 AutoReqProv:    on
 License:        LGPLv2.1
-Source:         
http://dl.sourceforge.net/sourceforge/lxc/lxc-%{version}.tar.bz2
+Source:         %{name}-%{version}.tar.bz2
 Source1:        README.SUSE
 BuildRoot:      %{_tmppath}/%{name}-%{version}-build
 BuildRequires:  docbook-utils libcap-devel pkg-config
@@ -46,50 +46,32 @@
 package is useful to create Virtual Private Server, or to run isolated
 applications like bash or sshd.
 
-
-
-Authors:
---------
-    Daniel Lezcano <dlezcano at fr.ibm.com>
-
 %package devel
 License:        LGPLv2.1
 Summary:        Development library for lxc
-Requires:       %{name} = %{version} glibc-devel
+Requires:       %name = %version glibc-devel
 Group:          Development/Libraries/C and C++
 
 %description devel
 Lxc header files and library needed for development of containers.
 
-
-
-Authors:
---------
-    Daniel Lezcano <dlezcano at fr.ibm.com>
-
 %prep
-%setup -q
+%setup
 
 %build
-aclocal -I config
-autoheader
-autoconf
-automake --add-missing --copy
-%configure --libexecdir=%{_prefix}/lib/%{name} --disable-examples
-%{__make} %{?jobs:-j%jobs}
-cp %{SOURCE1} .
-# copy to separate dir do we can use rpm's %%doc
-rm -rf .doc
-mkdir -p .doc/examples
-cp doc/examples/*.conf .doc/examples
+%configure --disable-examples
+%__make %{?_smp_mflags}
+%__cp %{SOURCE1} .
+%__rm -rf .doc
+%__mkdir_p .doc/examples
+%__cp doc/examples/*.conf .doc/examples
 
 %install
 %makeinstall
-install -d -m 755 %{buildroot}/var/lib/lxc
-find $RPM_BUILD_ROOT -type f -name '*.la' -exec rm -f {} ';'
+find %buildroot -type f -name '*.la' -delete
 
 %clean
-rm -rf %{buildroot}
+%__rm -rf %buildroot
 
 %post -p /sbin/ldconfig
 
@@ -97,18 +79,18 @@
 
 %files
 %defattr(-,root,root)
-%doc AUTHORS MAINTAINERS COPYING README
+%doc AUTHORS MAINTAINERS COPYING README doc/FAQ.txt
 %doc README.SUSE
 %doc .doc/examples
-%{_libdir}/liblxc.so.*
-%{_libdir}/lxc
+%{_libdir}/lib%{name}.so.*
+%{_libdir}/%name
 %{_bindir}/%{name}-*
 %{_mandir}/man[^3]/*
 
 %files devel
 %defattr(-,root,root)
-%{_includedir}/%{name}
-%{_libdir}/liblxc.so
+%{_includedir}/%name
+%{_libdir}/lib%{name}.so
 %{_datadir}/pkgconfig/%{name}.pc
 
 %changelog

++++++ _service ++++++
--- /var/tmp/diff_new_pack.SfsvqN/_old  2011-04-01 10:09:20.000000000 +0200
+++ /var/tmp/diff_new_pack.SfsvqN/_new  2011-04-01 10:09:20.000000000 +0200
@@ -1,11 +1,11 @@
 <services>
  <service name="download_url">
-   <param name="protocol">http</param>
    <param name="host">lxc.sourceforge.net</param>
-   <param name="path">/download/lxc/lxc-0.7.4.tar.gz</param>
+   <param name="protocol">http</param>
+   <param name="path">/download/lxc/lxc-0.7.4.1.tar.gz</param>
  </service>
  <service name="recompress">
-   <param name="file">_service:download_url:lxc-0.7.4.tar.gz</param>
+   <param name="file">_service:download_url:lxc-*.tar.gz</param>
    <param name="compression">bz2</param>
  </service>
 </services>

++++++ _service:recompress:download_url:lxc-0.7.4.tar.bz2 -> 
_service:recompress:download_url:lxc-0.7.4.1.tar.bz2 ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/configure new/lxc-0.7.4.1/configure
--- old/lxc-0.7.4/configure     2011-02-26 10:20:20.000000000 +0100
+++ new/lxc-0.7.4.1/configure   2011-03-14 21:48:53.000000000 +0100
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.67 for lxc 0.7.4.
+# Generated by GNU Autoconf 2.67 for lxc 0.7.4.1.
 #
 #
 # Copyright (C) 1992, 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2001,
@@ -549,8 +549,8 @@
 # Identity of this package.
 PACKAGE_NAME='lxc'
 PACKAGE_TARNAME='lxc'
-PACKAGE_VERSION='0.7.4'
-PACKAGE_STRING='lxc 0.7.4'
+PACKAGE_VERSION='0.7.4.1'
+PACKAGE_STRING='lxc 0.7.4.1'
 PACKAGE_BUGREPORT=''
 PACKAGE_URL=''
 
@@ -1266,7 +1266,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures lxc 0.7.4 to adapt to many kinds of systems.
+\`configure' configures lxc 0.7.4.1 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1336,7 +1336,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of lxc 0.7.4:";;
+     short | recursive ) echo "Configuration of lxc 0.7.4.1:";;
    esac
   cat <<\_ACEOF
 
@@ -1433,7 +1433,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-lxc configure 0.7.4
+lxc configure 0.7.4.1
 generated by GNU Autoconf 2.67
 
 Copyright (C) 2010 Free Software Foundation, Inc.
@@ -1777,7 +1777,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by lxc $as_me 0.7.4, which was
+It was created by lxc $as_me 0.7.4.1, which was
 generated by GNU Autoconf 2.67.  Invocation command line was
 
   $ $0 $@
@@ -2596,7 +2596,7 @@
 
 # Define the identity of the package.
  PACKAGE='lxc'
- VERSION='0.7.4'
+ VERSION='0.7.4.1'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -5591,7 +5591,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by lxc $as_me 0.7.4, which was
+This file was extended by lxc $as_me 0.7.4.1, which was
 generated by GNU Autoconf 2.67.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -5657,7 +5657,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; 
s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-lxc config.status 0.7.4
+lxc config.status 0.7.4.1
 configured by $0, generated by GNU Autoconf 2.67,
   with options \\"\$ac_cs_config\\"
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/configure.ac new/lxc-0.7.4.1/configure.ac
--- old/lxc-0.7.4/configure.ac  2011-02-26 10:18:19.000000000 +0100
+++ new/lxc-0.7.4.1/configure.ac        2011-03-14 21:48:10.000000000 +0100
@@ -1,7 +1,7 @@
 #                                               -*- Autoconf -*-
 # Process this file with autoconf to produce a configure script.
 
-AC_INIT([lxc], [0.7.4])
+AC_INIT([lxc], [0.7.4.1])
 
 AC_CONFIG_SRCDIR([configure.ac])
 AC_CONFIG_AUX_DIR([config])
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-cgroup.1 
new/lxc-0.7.4.1/doc/lxc-cgroup.1
--- old/lxc-0.7.4/doc/lxc-cgroup.1      2011-02-26 10:20:27.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-cgroup.1    2011-03-14 21:49:05.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-CGROUP" "1" "26 February 2011" "" ""
+.TH "LXC-CGROUP" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-cgroup \- manage the control group associated with a container
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-checkpoint.1 
new/lxc-0.7.4.1/doc/lxc-checkpoint.1
--- old/lxc-0.7.4/doc/lxc-checkpoint.1  2011-02-26 10:20:26.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-checkpoint.1        2011-03-14 21:49:03.000000000 
+0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-CHECKPOINT" "1" "26 February 2011" "IBM" ""
+.TH "LXC-CHECKPOINT" "1" "14 March 2011" "IBM" ""
 
 .SH NAME
 lxc-checkpoint \- checkpoint a running container (not implemented yet)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-console.1 
new/lxc-0.7.4.1/doc/lxc-console.1
--- old/lxc-0.7.4/doc/lxc-console.1     2011-02-26 10:20:26.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-console.1   2011-03-14 21:49:03.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-CONSOLE" "1" "26 February 2011" "" ""
+.TH "LXC-CONSOLE" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-console \- Launch a console for the specified container
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-create.1 
new/lxc-0.7.4.1/doc/lxc-create.1
--- old/lxc-0.7.4/doc/lxc-create.1      2011-02-26 10:20:25.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-create.1    2011-03-14 21:49:02.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-CREATE" "1" "26 February 2011" "" ""
+.TH "LXC-CREATE" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-create \- creates a container
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-destroy.1 
new/lxc-0.7.4.1/doc/lxc-destroy.1
--- old/lxc-0.7.4/doc/lxc-destroy.1     2011-02-26 10:20:25.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-destroy.1   2011-03-14 21:49:02.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-DESTROY" "1" "26 February 2011" "" ""
+.TH "LXC-DESTROY" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-destroy \- destroy a container.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-execute.1 
new/lxc-0.7.4.1/doc/lxc-execute.1
--- old/lxc-0.7.4/doc/lxc-execute.1     2011-02-26 10:20:25.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-execute.1   2011-03-14 21:49:02.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-EXECUTE" "1" "26 February 2011" "" ""
+.TH "LXC-EXECUTE" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-execute \- run an application inside a container.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-freeze.1 
new/lxc-0.7.4.1/doc/lxc-freeze.1
--- old/lxc-0.7.4/doc/lxc-freeze.1      2011-02-26 10:20:26.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-freeze.1    2011-03-14 21:49:04.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-FREEZE" "1" "26 February 2011" "" ""
+.TH "LXC-FREEZE" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-freeze \- freeze all the container's processes
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-kill.1 
new/lxc-0.7.4.1/doc/lxc-kill.1
--- old/lxc-0.7.4/doc/lxc-kill.1        2011-02-26 10:20:27.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-kill.1      2011-03-14 21:49:05.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-KILL" "1" "26 February 2011" "IBM" ""
+.TH "LXC-KILL" "1" "14 March 2011" "IBM" ""
 
 .SH NAME
 lxc-kill \- Send a signal to the process 1 of the container.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-ls.1 new/lxc-0.7.4.1/doc/lxc-ls.1
--- old/lxc-0.7.4/doc/lxc-ls.1  2011-02-26 10:20:27.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-ls.1        2011-03-14 21:49:04.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-LS" "1" "26 February 2011" "" ""
+.TH "LXC-LS" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-ls \- list the containers existing on the system
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-monitor.1 
new/lxc-0.7.4.1/doc/lxc-monitor.1
--- old/lxc-0.7.4/doc/lxc-monitor.1     2011-02-26 10:20:27.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-monitor.1   2011-03-14 21:49:04.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-MONITOR" "1" "26 February 2011" "" ""
+.TH "LXC-MONITOR" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-monitor \- monitor the container state
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-ps.1 new/lxc-0.7.4.1/doc/lxc-ps.1
--- old/lxc-0.7.4/doc/lxc-ps.1  2011-02-26 10:20:27.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-ps.1        2011-03-14 21:49:05.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-PS" "1" "26 February 2011" "" ""
+.TH "LXC-PS" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-ps \- list the processes belonging to a specific container.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-restart.1 
new/lxc-0.7.4.1/doc/lxc-restart.1
--- old/lxc-0.7.4/doc/lxc-restart.1     2011-02-26 10:20:26.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-restart.1   2011-03-14 21:49:03.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-RESTART" "1" "26 February 2011" "IBM" ""
+.TH "LXC-RESTART" "1" "14 March 2011" "IBM" ""
 
 .SH NAME
 lxc-restart \- restart a container from a file (not implemented yet)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-start.1 
new/lxc-0.7.4.1/doc/lxc-start.1
--- old/lxc-0.7.4/doc/lxc-start.1       2011-02-26 10:20:25.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-start.1     2011-03-14 21:49:03.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-START" "1" "26 February 2011" "" ""
+.TH "LXC-START" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-start \- run an application inside a container.
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-stop.1 
new/lxc-0.7.4.1/doc/lxc-stop.1
--- old/lxc-0.7.4/doc/lxc-stop.1        2011-02-26 10:20:26.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-stop.1      2011-03-14 21:49:03.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-STOP" "1" "26 February 2011" "" ""
+.TH "LXC-STOP" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-stop \- stop the application running inside a container
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-unfreeze.1 
new/lxc-0.7.4.1/doc/lxc-unfreeze.1
--- old/lxc-0.7.4/doc/lxc-unfreeze.1    2011-02-26 10:20:26.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-unfreeze.1  2011-03-14 21:49:04.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-UNFREEZE" "1" "26 February 2011" "" ""
+.TH "LXC-UNFREEZE" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-unfreeze \- thaw all the container's processes
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc-wait.1 
new/lxc-0.7.4.1/doc/lxc-wait.1
--- old/lxc-0.7.4/doc/lxc-wait.1        2011-02-26 10:20:27.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc-wait.1      2011-03-14 21:49:04.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC-WAIT" "1" "26 February 2011" "" ""
+.TH "LXC-WAIT" "1" "14 March 2011" "" ""
 
 .SH NAME
 lxc-wait \- wait for a specific container state
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc.7 new/lxc-0.7.4.1/doc/lxc.7
--- old/lxc-0.7.4/doc/lxc.7     2011-02-26 10:20:28.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc.7   2011-03-14 21:49:06.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC" "7" "26 February 2011" "Version 0.7.4" ""
+.TH "LXC" "7" "14 March 2011" "Version 0.7.4.1" ""
 
 .SH NAME
 lxc \- linux containers
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/doc/lxc.conf.5 
new/lxc-0.7.4.1/doc/lxc.conf.5
--- old/lxc-0.7.4/doc/lxc.conf.5        2011-02-26 10:20:28.000000000 +0100
+++ new/lxc-0.7.4.1/doc/lxc.conf.5      2011-03-14 21:49:05.000000000 +0100
@@ -3,7 +3,7 @@
 .\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
 .\" Please send any bug reports, improvements, comments, patches, 
 .\" etc. to Steve Cheng <[email protected]>.
-.TH "LXC.CONF" "5" "26 February 2011" "" ""
+.TH "LXC.CONF" "5" "14 March 2011" "" ""
 
 .SH NAME
 lxc.conf \- linux container configuration file
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/lxc.spec new/lxc-0.7.4.1/lxc.spec
--- old/lxc-0.7.4/lxc.spec      2011-02-26 10:20:22.000000000 +0100
+++ new/lxc-0.7.4.1/lxc.spec    2011-03-14 21:48:58.000000000 +0100
@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 Name: lxc
-Version: 0.7.4
+Version: 0.7.4.1
 Release: 1
 URL: http://lxc.sourceforge.net
 Source: http://dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.gz
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/src/lxc/conf.c 
new/lxc-0.7.4.1/src/lxc/conf.c
--- old/lxc-0.7.4/src/lxc/conf.c        2011-02-02 21:55:49.000000000 +0100
+++ new/lxc-0.7.4.1/src/lxc/conf.c      2011-03-14 21:47:52.000000000 +0100
@@ -979,7 +979,7 @@
                goto out;
        }
 
-       snprintf(path, MAXPATHLEN, "%s%s", rootfs->mount,
+       snprintf(path, MAXPATHLEN, "%s/%s", rootfs->mount,
                 aux + strlen(rootfs->path));
 
        ret = mount_entry(mntent->mnt_fsname, path, mntent->mnt_type,
@@ -1218,7 +1218,7 @@
        /* empty network namespace */
        if (!netdev->ifindex) {
                if (netdev->flags & IFF_UP) {
-                       err = lxc_device_up("lo");
+                       err = lxc_netdev_up("lo");
                        if (err) {
                                ERROR("failed to set the loopback up : %s",
                                      strerror(-err));
@@ -1241,7 +1241,7 @@
                        netdev->link : "eth%d";
 
        /* rename the interface name */
-       err = lxc_device_rename(ifname, netdev->name);
+       err = lxc_netdev_rename_by_name(ifname, netdev->name);
        if (err) {
                ERROR("failed to rename %s->%s : %s", ifname, netdev->name,
                      strerror(-err));
@@ -1284,7 +1284,7 @@
        if (netdev->flags & IFF_UP) {
                int err;
 
-               err = lxc_device_up(current_ifname);
+               err = lxc_netdev_up(current_ifname);
                if (err) {
                        ERROR("failed to set '%s' up : %s", current_ifname,
                              strerror(-err));
@@ -1292,7 +1292,7 @@
                }
 
                /* the network is up, make the loopback up too */
-               err = lxc_device_up("lo");
+               err = lxc_netdev_up("lo");
                if (err) {
                        ERROR("failed to set the loopback up : %s",
                              strerror(-err));
@@ -1381,9 +1381,9 @@
        }
 
        if (netdev->mtu) {
-               err = lxc_device_set_mtu(veth1, atoi(netdev->mtu));
+               err = lxc_netdev_set_mtu(veth1, atoi(netdev->mtu));
                if (!err)
-                       err = lxc_device_set_mtu(veth2, atoi(netdev->mtu));
+                       err = lxc_netdev_set_mtu(veth2, atoi(netdev->mtu));
                if (err) {
                        ERROR("failed to set mtu '%s' for %s-%s : %s",
                              netdev->mtu, veth1, veth2, strerror(-err));
@@ -1406,7 +1406,7 @@
                goto out_delete;
        }
 
-       err = lxc_device_up(veth1);
+       err = lxc_netdev_up(veth1);
        if (err) {
                ERROR("failed to set %s up : %s", veth1, strerror(-err));
                goto out_delete;
@@ -1425,7 +1425,7 @@
        return 0;
 
 out_delete:
-       lxc_device_delete(veth1);
+       lxc_netdev_delete_by_name(veth1);
        return -1;
 }
 
@@ -1458,7 +1458,7 @@
        netdev->ifindex = if_nametoindex(peer);
        if (!netdev->ifindex) {
                ERROR("failed to retrieve the index for %s", peer);
-               lxc_device_delete(peer);
+               lxc_netdev_delete_by_name(peer);
                return -1;
        }
 
@@ -1498,7 +1498,7 @@
        netdev->ifindex = if_nametoindex(peer);
        if (!netdev->ifindex) {
                ERROR("failed to retrieve the ifindex for %s", peer);
-               lxc_device_delete(peer);
+               lxc_netdev_delete_by_name(peer);
                return -1;
        }
 
@@ -1578,8 +1578,16 @@
 
        lxc_list_for_each(iterator, network) {
                netdev = iterator->elem;
-               if (netdev->ifindex > 0 && netdev->type != LXC_NET_PHYS)
-                       lxc_device_delete_index(netdev->ifindex);
+               if (netdev->ifindex == 0)
+                       continue;
+
+               /* Recent kernels already delete the virtual devices */
+               if (netdev->type != LXC_NET_PHYS)
+                       continue;
+
+               if (lxc_netdev_rename_by_index(netdev->ifindex, netdev->link))
+                       WARN("failed to rename to the initial name the netdev 
'%s'",
+                            netdev->link);
        }
 }
 
@@ -1597,7 +1605,7 @@
                if (!netdev->ifindex)
                        continue;
 
-               err = lxc_device_move(netdev->ifindex, pid);
+               err = lxc_netdev_move_by_index(netdev->ifindex, pid);
                if (err) {
                        ERROR("failed to move '%s' to the container : %s",
                              netdev->link, strerror(-err));
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/src/lxc/log.c new/lxc-0.7.4.1/src/lxc/log.c
--- old/lxc-0.7.4/src/lxc/log.c 2010-10-11 15:49:37.000000000 +0200
+++ new/lxc-0.7.4.1/src/lxc/log.c       2011-03-11 23:03:44.000000000 +0100
@@ -151,7 +151,7 @@
 extern int lxc_log_init(const char *file, const char *priority,
                        const char *prefix, int quiet)
 {
-       int lxc_priority = LXC_LOG_PRIORITY_ERROR;
+       int lxc_priority = LXC_LOG_PRIORITY_WARN;
 
        if (priority) {
                lxc_priority = lxc_log_priority_to_int(priority);
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/src/lxc/network.h 
new/lxc-0.7.4.1/src/lxc/network.h
--- old/lxc-0.7.4/src/lxc/network.h     2010-10-08 11:54:53.000000000 +0200
+++ new/lxc-0.7.4.1/src/lxc/network.h   2011-03-07 12:41:35.000000000 +0100
@@ -31,51 +31,36 @@
 /*
  * Move a device between namespaces
  */
-extern int lxc_device_move(int ifindex, pid_t pid);
+extern int lxc_netdev_move_by_index(int ifindex, pid_t pid);
 
 /*
  * Delete a network device
  */
-extern int lxc_device_delete(const char *name);
+extern int lxc_netdev_delete_by_name(const char *name);
+extern int lxc_netdev_delete_by_index(int ifindex);
 
 /*
- * Delete a network device by the index
- */
-extern int lxc_device_delete_index(int ifindex);
-
-/*
- * Set the device network up
+ * Change the device name
  */
-extern int lxc_device_up(const char *name);
+extern int lxc_netdev_rename_by_name(const char *oldname, const char *newname);
+extern int lxc_netdev_rename_by_index(int ifindex, const char *newname);
 
 /*
- * Set the device network down
+ * Set the device network up or down
  */
-extern int lxc_device_down(const char *name);
-
-/*
- * Change the device name
- */
-extern int lxc_device_rename(const char *oldname, const char *newname);
+extern int lxc_netdev_up(const char *name);
+extern int lxc_netdev_down(const char *name);
 
 /*
  * Change the mtu size for the specified device
  */
-extern int lxc_device_set_mtu(const char *name, int mtu);
+extern int lxc_netdev_set_mtu(const char *name, int mtu);
 
 /*
- * Create a veth network device
+ * Create a virtual network devices
  */
 extern int lxc_veth_create(const char *name1, const char *name2);
-
-/* 
- * Create a macvlan network device
- */
 extern int lxc_macvlan_create(const char *master, const char *name, int mode);
-
-/*
- * Create a vlan network device
- */
 extern int lxc_vlan_create(const char *master, const char *name, ushort vid);
 
 /*
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/src/lxc/setns.h 
new/lxc-0.7.4.1/src/lxc/setns.h
--- old/lxc-0.7.4/src/lxc/setns.h       2011-01-19 14:53:05.000000000 +0100
+++ new/lxc-0.7.4.1/src/lxc/setns.h     2011-03-07 02:09:02.000000000 +0100
@@ -1 +0,0 @@
-#define __NR_setns 303


++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++



Remember to have fun...

diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/lxc-0.7.4/src/lxc/network.c 
new/lxc-0.7.4.1/src/lxc/network.c
--- old/lxc-0.7.4/src/lxc/network.c     2011-02-14 09:22:02.000000000 +0100
+++ new/lxc-0.7.4.1/src/lxc/network.c   2011-03-07 12:41:35.000000000 +0100
@@ -89,7 +89,7 @@
        struct ifaddrmsg ifa;
 };
 
-int lxc_device_move(int ifindex, pid_t pid)
+int lxc_netdev_move_by_index(int ifindex, pid_t pid)
 {
        struct nl_handler nlh;
        struct nlmsg *nlmsg = NULL;
@@ -122,22 +122,17 @@
        return err;
 }
 
-int lxc_device_delete(const char *name)
+int lxc_netdev_delete_by_index(int ifindex)
 {
        struct nl_handler nlh;
        struct nlmsg *nlmsg = NULL, *answer = NULL;
        struct link_req *link_req;
-       int index, len, err;
+       int err;
 
        err = netlink_open(&nlh, NETLINK_ROUTE);
        if (err)
                return err;
 
-       err = -EINVAL;
-       len = strlen(name);
-       if (len == 1 || len > IFNAMSIZ)
-               goto out;
-
        err = -ENOMEM;
        nlmsg = nlmsg_alloc(NLMSG_GOOD_SIZE);
        if (!nlmsg)
@@ -147,21 +142,13 @@
        if (!answer)
                goto out;
 
-       err = -EINVAL;
-       index = if_nametoindex(name);
-       if (!index)
-               goto out;
-
        link_req = (struct link_req *)nlmsg;
        link_req->ifinfomsg.ifi_family = AF_UNSPEC;
-       link_req->ifinfomsg.ifi_index = index;
+       link_req->ifinfomsg.ifi_index = ifindex;
        nlmsg->nlmsghdr.nlmsg_len = NLMSG_LENGTH(sizeof(struct ifinfomsg));
        nlmsg->nlmsghdr.nlmsg_flags = NLM_F_ACK|NLM_F_REQUEST;
        nlmsg->nlmsghdr.nlmsg_type = RTM_DELLINK;
 
-       if (nla_put_string(nlmsg, IFLA_IFNAME, name))
-               goto out;
-
        err = netlink_transaction(&nlh, nlmsg, answer);
 out:
        netlink_close(&nlh);
@@ -170,17 +157,32 @@
        return err;
 }
 
-int lxc_device_delete_index(int ifindex)
+int lxc_netdev_delete_by_name(const char *name)
+{
+       int index;
+
+       index = if_nametoindex(name);
+       if (!index)
+               return -EINVAL;
+
+       return lxc_netdev_delete_by_index(index);
+}
+
+int lxc_netdev_rename_by_index(int ifindex, const char *newname)
 {
        struct nl_handler nlh;
        struct nlmsg *nlmsg = NULL, *answer = NULL;
        struct link_req *link_req;
-       int err;
+       int len, err;
 
        err = netlink_open(&nlh, NETLINK_ROUTE);
        if (err)
                return err;
 
+       len = strlen(newname);
+       if (len == 1 || len > IFNAMSIZ)
+               goto out;
+
        err = -ENOMEM;
        nlmsg = nlmsg_alloc(NLMSG_GOOD_SIZE);
        if (!nlmsg)
@@ -195,7 +197,10 @@
        link_req->ifinfomsg.ifi_index = ifindex;
        nlmsg->nlmsghdr.nlmsg_len = NLMSG_LENGTH(sizeof(struct ifinfomsg));
        nlmsg->nlmsghdr.nlmsg_flags = NLM_F_ACK|NLM_F_REQUEST;
-       nlmsg->nlmsghdr.nlmsg_type = RTM_DELLINK;
+       nlmsg->nlmsghdr.nlmsg_type = RTM_NEWLINK;
+
+       if (nla_put_string(nlmsg, IFLA_IFNAME, newname))
+               goto out;
 
        err = netlink_transaction(&nlh, nlmsg, answer);
 out:
@@ -205,7 +210,22 @@
        return err;
 }
 
-static int device_set_flag(const char *name, int flag)
+int lxc_netdev_rename_by_name(const char *oldname, const char *newname)
+{
+       int len, index;
+
+       len = strlen(oldname);
+       if (len == 1 || len > IFNAMSIZ)
+               return -EINVAL;
+
+       index = if_nametoindex(oldname);
+       if (!index)
+               return -EINVAL;
+
+       return lxc_netdev_rename_by_index(index, newname);
+}
+
+static int netdev_set_flag(const char *name, int flag)
 {
        struct nl_handler nlh;
        struct nlmsg *nlmsg = NULL, *answer = NULL;
@@ -252,7 +272,7 @@
        return err;
 }
 
-int lxc_device_set_mtu(const char *name, int mtu)
+int lxc_netdev_set_mtu(const char *name, int mtu)
 {
        struct nl_handler nlh;
        struct nlmsg *nlmsg = NULL, *answer = NULL;
@@ -300,66 +320,14 @@
        return err;
 }
 
-int lxc_device_up(const char *name)
+int lxc_netdev_up(const char *name)
 {
-       return device_set_flag(name, IFF_UP);
+       return netdev_set_flag(name, IFF_UP);
 }
 
-int lxc_device_down(const char *name)
+int lxc_netdev_down(const char *name)
 {
-       return device_set_flag(name, 0);
-}
-
-int lxc_device_rename(const char *oldname, const char *newname)
-{
-       struct nl_handler nlh;
-       struct nlmsg *nlmsg = NULL, *answer = NULL;
-       struct link_req *link_req;
-       int index, len, err;
-
-       err = netlink_open(&nlh, NETLINK_ROUTE);
-       if (err)
-               return err;
-
-       err = -EINVAL;
-       len = strlen(oldname);
-       if (len == 1 || len > IFNAMSIZ)
-               goto out;
-
-       len = strlen(newname);
-       if (len == 1 || len > IFNAMSIZ)
-               goto out;
-
-       err = -ENOMEM;
-       nlmsg = nlmsg_alloc(NLMSG_GOOD_SIZE);
-       if (!nlmsg)
-               goto out;
-
-       answer = nlmsg_alloc(NLMSG_GOOD_SIZE);
-       if (!answer)
-               goto out;
-
-       err = -EINVAL;
-       index = if_nametoindex(oldname);
-       if (!index)
-               goto out;
-
-       link_req = (struct link_req *)nlmsg;
-       link_req->ifinfomsg.ifi_family = AF_UNSPEC;
-       link_req->ifinfomsg.ifi_index = index;
-       nlmsg->nlmsghdr.nlmsg_len = NLMSG_LENGTH(sizeof(struct ifinfomsg));
-       nlmsg->nlmsghdr.nlmsg_flags = NLM_F_ACK|NLM_F_REQUEST;
-       nlmsg->nlmsghdr.nlmsg_type = RTM_NEWLINK;
-
-       if (nla_put_string(nlmsg, IFLA_IFNAME, newname))
-               goto out;
-
-       err = netlink_transaction(&nlh, nlmsg, answer);
-out:
-       netlink_close(&nlh);
-       nlmsg_free(answer);
-       nlmsg_free(nlmsg);
-       return err;
+       return netdev_set_flag(name, 0);
 }
 
 int lxc_veth_create(const char *name1, const char *name2)
@@ -775,7 +743,7 @@
 
 /*
  * There is a lxc_bridge_attach, but no need of a bridge detach
  * as automatically done by kernel when device deleted.
  */
 int lxc_bridge_attach(const char *bridge, const char *ifname)
 {
@@ -775,7 +743,7 @@
 /*
  * There is a lxc_bridge_attach, but no need of a bridge detach
- * as automatically done by kernel when device deleted.
+ * as automatically done by kernel when a netdev is deleted.
  */
 int lxc_bridge_attach(const char *bridge, const char *ifname)
-- 
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to